{% load static %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <title>{% block title %}psutil-dash{% endblock %}</title>

    <link rel="stylesheet" href="{% static 'psutildash/css/tabler.min.css' %}">
</head>
<body>

    {% block body %}{% endblock %}

    <script src="{% static 'psutildash/js/tabler.min.js' %}"></script>
</body>
</html>